@@ -1,5 +1,3 @@
-// -*- C++ -*-
-
 /* parse_error.h
  *
  * Copyright (C) 2002 The libxml++ development team
@@ -24,23 +22,19 @@
 
 #include <libxml++/exceptions/exception.h>
 
-#include <exception>
-#include <glibmm/ustring.h>
-
 namespace xmlpp
 {
 
 /** This exception will be thrown when the parser encounters an error in the XML document.
- */  
-class parse_error: public exception
+ */
+class LIBXMLPP_API parse_error : public exception
 {
 public:
-  LIBXMLPP_API
   explicit parse_error(const Glib::ustring& message);
-  LIBXMLPP_API ~parse_error() noexcept override;
+  ~parse_error() noexcept override;
 
-  LIBXMLPP_API void Raise() const override;
-  LIBXMLPP_API exception* Clone() const override;
+  void raise() const override;
+  exception* clone() const override;
 };
 
 } // namespace xmlpp
