@@ -1,5 +1,3 @@
-// -*- C++ -*-
-
 /* validity_error.h
  *
  * Copyright (C) 2002 The libxml++ development team
@@ -29,15 +27,14 @@ namespace xmlpp
 
 /** This exception will be thrown when the parser encounters a validity error in the XML document.
  */
-class validity_error: public parse_error
+class LIBXMLPP_API validity_error : public parse_error
 {
 public:
-  LIBXMLPP_API
   explicit validity_error(const Glib::ustring& message);
-  LIBXMLPP_API ~validity_error() noexcept override;
+  ~validity_error() noexcept override;
 
-  LIBXMLPP_API void Raise() const override;
-  LIBXMLPP_API exception* Clone() const override;
+  void raise() const override;
+  exception* clone() const override;
 };
 
 } // namespace xmlpp
