@@ -7,10 +7,6 @@
 #ifndef __LIBXMLPP_PARSER_H
 #define __LIBXMLPP_PARSER_H
 
-#ifdef _MSC_VER //Ignore warnings about the Visual C++ Bug, where we can not do anything
-#pragma warning (disable : 4786)
-#endif
-
 #include <libxml++/nodes/element.h>
 #include <libxml++/exceptions/validity_error.h>
 #include <libxml++/exceptions/internal_error.h>
@@ -32,7 +28,7 @@ namespace xmlpp {
  *
  * Abstract base class for DOM parser and SAX parser.
  */
-class Parser : public NonCopyable
+class LIBXMLPP_API Parser : public NonCopyable
 {
 public:
   Parser();
@@ -112,7 +108,7 @@ public:
    *
    * @returns Whether attributes with default values will be included in the node tree.
    */
-  bool get_include_default_attributes() noexcept;
+  bool get_include_default_attributes() const noexcept;
 
   /** Set and/or clear parser option flags.
    * See the libxml2 documentation, enum xmlParserOption, for a list of parser options.
@@ -132,11 +128,11 @@ public:
    *
    * @newin{2,38}
    *
-   * @param [out] set_options Set bits correspond to flags that shall be set during parsing.
-   * @param [out] clear_options Set bits correspond to flags that shall be cleared during parsing.
+   * @param[out] set_options Set bits correspond to flags that shall be set during parsing.
+   * @param[out] clear_options Set bits correspond to flags that shall be cleared during parsing.
    *        Bits that are set in neither @a set_options nor @a clear_options are not affected.
    */
-  void get_parser_options(int& set_options, int& clear_options) noexcept;
+  void get_parser_options(int& set_options, int& clear_options) const noexcept;
 
   /** Parse an XML document from a file.
    * @throw exception
@@ -196,11 +192,6 @@ protected:
   static void callback_error_or_warning(MsgType msg_type, void* ctx,
                                         const char* msg, va_list var_args);
 
-  //TODO: When we can break ABI, remove set/get_xinclude_options_internal()
-  // and move all XInclude stuff to DomParser.
-  void set_xinclude_options_internal(int xinclude_options) noexcept;
-  int get_xinclude_options_internal() const noexcept;
-
   _xmlParserCtxt* context_;
   std::unique_ptr<exception> exception_;
 
