@@ -22,27 +22,27 @@
 #define __LIBXMLPP_VALIDATOR_RELAXNGVALIDATOR_H
 
 #include <libxml++/validators/schemavalidatorbase.h>
-#include <memory> // std::auto_ptr
+#include <memory> // std::unique_ptr
 
 namespace Glib
 {
-class ustring;
+class LIBXMLPP_API ustring;
 }
 
 namespace xmlpp
 {
-class Document;
-class RelaxNGSchema;
+class LIBXMLPP_API Document;
+class LIBXMLPP_API RelaxNGSchema;
 
 /** RelaxNG schema validator.
  * RelaxNG = REgular LAnguage for XML Next Generation
  *
  * @newin{2,38}
  */
-class RelaxNGValidator : public SchemaValidatorBase
+class LIBXMLPP_API RelaxNGValidator : public SchemaValidatorBase
 {
 public:
-  LIBXMLPP_API RelaxNGValidator();
+  RelaxNGValidator();
 
   /** Create a validator and parse a schema definition file.
    * The schema must be defined with XML syntax (.rng file). The compact syntax
@@ -50,14 +50,12 @@ public:
    * @param filename The URL of the schema.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
-  explicit RelaxNGValidator(const Glib::ustring& filename);
+  explicit RelaxNGValidator(const std::string& filename);
 
   /** Create a validator and parse a schema definition document.
    * @param document A preparsed document tree, containing the schema definition.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
   explicit RelaxNGValidator(const Document* document);
 
   /** Create a validator.
@@ -69,13 +67,9 @@ public:
    *        validator keeps a pointer to it. The caller is responsible for
    *        deleting the schema when it's no longer needed.
    */
-  LIBXMLPP_API
   explicit RelaxNGValidator(RelaxNGSchema* schema, bool take_ownership);
 
-  LIBXMLPP_API ~RelaxNGValidator() override;
-
-  //TODO: Remove virtuals when we can break ABI,
-  //or really put these in the base class.
+  ~RelaxNGValidator() override;
 
   /** Parse a schema definition file.
    * The schema must be defined with XML syntax (.rng file). The compact syntax
@@ -86,8 +80,7 @@ public:
    * @param filename The URL of the schema.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
-  void parse_file(const Glib::ustring& filename) override;
+  void parse_file(const std::string& filename) override;
 
   /** Parse a schema definition from a string.
    * The schema must be defined with XML syntax. The compact syntax is not supported.
@@ -97,7 +90,6 @@ public:
    * @param contents The schema definition as a string.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
   void parse_memory(const Glib::ustring& contents) override;
 
   /** Parse a schema definition from a document.
@@ -106,7 +98,6 @@ public:
    * @param document A preparsed document tree, containing the schema definition.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
   void parse_document(const Document* document) override;
 
   /** Set a schema.
@@ -120,7 +111,6 @@ public:
    *        validator keeps a pointer to it. The caller is responsible for
    *        deleting the schema when it's no longer needed.
    */
-  LIBXMLPP_API
   void set_schema(RelaxNGSchema* schema, bool take_ownership);
 
   /** Test whether a schema has been parsed.
@@ -130,26 +120,23 @@ public:
    *   do_something();
    * @endcode
    */
-  LIBXMLPP_API
-  operator BoolExpr() const override;
+  explicit operator bool() const noexcept override;
 
   /** Get the schema.
    * @returns A pointer to the schema, or <tt>nullptr</tt>.
    */
-  LIBXMLPP_API RelaxNGSchema* get_schema();
+  RelaxNGSchema* get_schema() noexcept;
 
   /** Get the schema.
    * @returns A pointer to the schema, or <tt>nullptr</tt>.
    */
-  LIBXMLPP_API
-  const RelaxNGSchema* get_schema() const;
+  const RelaxNGSchema* get_schema() const noexcept;
 
   /** Validate a document, using a previously parsed schema.
    * @param document Pointer to the document.
    * @throws xmlpp::internal_error
    * @throws xmlpp::validity_error
    */
-  LIBXMLPP_API
   void validate(const Document* document) override;
 
   /** Validate an XML file, using a previously parsed schema.
@@ -158,18 +145,15 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  LIBXMLPP_API
-  void validate(const Glib::ustring& filename) override;
+  void validate(const std::string& filename) override;
 
 protected:
-  LIBXMLPP_API
-  void initialize_valid() override;
-  LIBXMLPP_API
+  void initialize_context() override;
   void release_underlying() override;
 
 private:
   struct Impl;
-  std::auto_ptr<Impl> pimpl_;
+  std::unique_ptr<Impl> pimpl_;
 };
 
 } // namespace xmlpp
